@@ -1,11 +1,13 @@
-import numpy as np
-from pathlib import Path
 import json
-import flammkuchen as fl
-from split_dataset.blocks import Blocks
 import warnings
 from itertools import product
+from pathlib import Path
+
+import flammkuchen as fl
 import h5py
+import numpy as np
+
+from split_dataset.blocks import Blocks
 
 
 # TODO this should probably be done as a constructor of the SplitDataset
@@ -18,8 +20,7 @@ def save_to_split_dataset(
     prefix="",
     compression="blosc",
 ):
-    """ Function to save block of data into a split_dataset.
-    """
+    """Function to save block of data into a split_dataset."""
 
     new_name = prefix + ("_cropped" if crop is not None else "")
     padding = (
@@ -54,8 +55,9 @@ class SplitDataset(Blocks):
     def __init__(self, root, prefix=None):
         """
         :param root: The directory containing the files
-        :param prefix: The class assumes individual file names to be xxxx.h5. If there is a prefix to this,
-        for example if the files are stack_xxxx.h5 this has to be passed to the object as a string, in this
+        :param prefix: The class assumes individual file names to be xxxx.h5.
+        If there is a prefix to this, for example if the files are stack_xxxx.h5
+        this has to be passed to the object as a string, in this
         particular case it would be prefix="stack_"
         """
 
@@ -98,12 +100,12 @@ class SplitDataset(Blocks):
             shape_block=block_metadata["shape_block"],
         )
 
-        if prefix != None:
-            files = sorted(self.root.glob("*{}_[0-9]*.h5".format(prefix)))
-        else:
+        if prefix is None:
             files = sorted(self.root.glob("*[0-9]*.h5"))
-        self.files = np.array(files).reshape(self.block_starts.shape[:-1])
+        else:
+            files = sorted(self.root.glob("*{}_[0-9]*.h5".format(prefix)))
 
+        self.files = np.array(files).reshape(self.block_starts.shape[:-1])
 
         # If available, read resolution
         try:
@@ -113,10 +115,13 @@ class SplitDataset(Blocks):
         # TODO check this
         self.shape = self.shape_cropped
 
+    @property
+    def ndim(self):
+        return len(self.shape)
+
     @property
     def data_key(self):
-        """To migrate smoothly to removal of stack_ND key in favour of only stack
-        """
+        """To migrate smoothly to removal of stack_ND key in favour of only stack"""
         return [k for k in fl.meta(self.files.flatten()[0]).keys() if "stack" in k][0]
 
     def __getitem__(self, item):
@@ -178,7 +183,7 @@ class SplitDataset(Blocks):
                             ends.append(min(dim_slc.stop, dim_full))
                         else:
                             ends.append(max(0, dim_full + dim_slc.stop))
-                elif isinstance(dim_slc, int) or isinstance(dim_slc, np.int32):
+                elif type(dim_slc) in [int, np.int32, np.int64]:
                     singletons[i_dim] = True
                     if dim_slc >= 0:
                         if dim_slc > dim_full - 1:
@@ -220,7 +225,9 @@ class SplitDataset(Blocks):
                 )
             )
             arr = fl.load(
-                str(self.files[f_idx]), "/" + self.data_key, sel=fl.aslice[sel_slices],
+                str(self.files[f_idx]),
+                "/" + self.data_key,
+                sel=fl.aslice[sel_slices],
             )
 
             if output is None:
@@ -250,26 +257,26 @@ class SplitDataset(Blocks):
         return output[output_sel]
 
     def as_dask(self):
-        """ Function to create a Dask array from a split dataset.
-           :param dataset: SplitDataset object
-           :return:
-           Dask array
-           """
+        """Function to create a Dask array from a split dataset.
+        :param dataset: SplitDataset object
+        :return:
+        Dask array
+        """
         import dask.array as da
 
         arrays = np.empty(self.files.shape, dtype=object)
 
         for s, _ in self.slices():
             arrays[s] = da.from_array(
-                h5py.File(self.files[s], mode="r")[f"/{self.data_key}"])
+                h5py.File(self.files[s], mode="r")[f"/{self.data_key}"]
+            )
 
         return da.block(arrays.tolist())
 
     def apply_crop(self, crop):
-        """ Take out the data with a crop
-
-        """
-        # TODO there is the crop atrribute, which is a lazy crop, this should actually return a non-cropped dataset
+        """Take out the data with a crop"""
+        # TODO there is the crop atrribute, which is a lazy crop, this should actually
+        #  return a non-cropped dataset
         ds_cropped = EmptySplitDataset(
             shape_full=self.shape,
             shape_block=self.shape_block,
@@ -291,7 +298,7 @@ class SplitDataset(Blocks):
 
 
 class EmptySplitDataset(Blocks):
-    """ Class to initialize an empty dataset for which we have to save metadata
+    """Class to initialize an empty dataset for which we have to save metadata
     after filling its blocks.
     """
 
@@ -306,13 +313,13 @@ class EmptySplitDataset(Blocks):
         if not self.root.is_dir():
             self.root.mkdir(parents=True)
         else:
-            warnings.warn('Existing directory')
+            warnings.warn("Existing directory")
 
         self.files = ["{:04d}.h5".format(i) for i in range(self.n_blocks)]
         self.resolution = resolution
 
     def save_block_data(self, n, data, verbose=False):
-        """ Optional method to save data in a block. Often we don't use it,
+        """Optional method to save data in a block. Often we don't use it,
         as we directly save data in the parallelized function. Might be good to
         find ways of centralizing saving here?
         :param n: n of the block we are saving in;
@@ -327,7 +334,7 @@ class EmptySplitDataset(Blocks):
             if data.shape != self.shape_block:
                 print(" - data has different dimension from block!")
 
-        to_save = {f"stack": data}
+        to_save = {"stack": data}
 
         fl.save(str(self.root / fname), to_save, compression="blosc")
 
@@ -337,8 +344,9 @@ class EmptySplitDataset(Blocks):
         block_dict["shape_full"] = self.shape_cropped
         block_dict["crop_start"] = (0,) * n_dims
         block_dict["crop_end"] = (0,) * n_dims
-        block_dict["resolution"] = self.resolution \
-            if self.resolution is not None else (1,) * n_dims
+        block_dict["resolution"] = (
+            self.resolution if self.resolution is not None else (1,) * n_dims
+        )
 
         block_dict["axis_order"] = "tzyx" if n_dims == 4 else "zyx"
 
@@ -347,7 +355,7 @@ class EmptySplitDataset(Blocks):
 
 
 def _save_metadata_json(dictionary, root):
-    """ Save json file preventing type failures for stack shapes
+    """Save json file preventing type failures for stack shapes
     :param path: path for saving
     :param dictionary: dictionary to be saved
     :return:
