@@ -2,10 +2,12 @@
 
 """Tests for `split_dataset` package."""
 
-import unittest
 import shutil
-import numpy as np
 import tempfile
+import unittest
+
+import numpy as np
+
 from split_dataset import save_to_split_dataset
 
 
@@ -60,11 +62,7 @@ class TestSplitDataset(unittest.TestCase):
         bs = (10, 10)
         test_data = np.arange(np.product(di)).reshape(di)
 
-        sd = save_to_split_dataset(
-            test_data,
-            block_size=bs,
-            root_name=self.test_dir
-        )
+        sd = save_to_split_dataset(test_data, block_size=bs, root_name=self.test_dir)
 
         sd_full = sd[:, :]
         sd_dask = np.array(sd.as_dask())
